@@ -3,6 +3,7 @@ import os
 import requests
 import sys
 from datetime import datetime
+from typing import Dict
 
 # # TODO should not ignore this warning. Remove when the pkm certificate will
 # # be corrected
@@ -74,7 +75,7 @@ class PKMClient(object):
                     and 'application/json' in resp.headers['Content-Type']):
                 answer = resp.json()
         else:
-            error_message = (f"Call to PKM server failed: {resp}, "
+            error_message = (f"Call to PKM server on {url} failed: {resp}, "
                              f"{resp.headers}, {resp.text}")
             print(error_message, file=sys.stderr)
             answer = error_message
@@ -101,11 +102,14 @@ class PKMClient(object):
     def now(self):
         return datetime.now().strftime("%Y%m%d_%H%M%S")
 
-    def update_invocation(self, project_id, invocationId, status, resultsToAdd):
+    def update_invocation(self, project_id: str, invocationId: str, status: int,
+                          resultsToAdd: Dict[str, str]):
+        """
+        """
         invocationUpdate = dict()
         invocationUpdate["invocationID"] = invocationId
 
-        if status:
+        if status == 0:
             invocationUpdate["invocationStatus"] = "COMPLETED"
         else:
             invocationUpdate["invocationStatus"] = "FAILED"
@@ -156,14 +160,14 @@ class Log(object):
         status, result = self.pkm.call(method='POST',
                                        path=f"log/{self.project}",
                                        payload=[self.json()])
-        if self.invocation_id is not None:
+        if status != 0:
+            print(f"Logging {self.json()} failed with {status}: {result}",
+                  file=sys.stderr)
+        elif self.invocation_id is not None:
             newLogID = json.loads(result)[0]
             self.pkm.update_invocation(
                 self.project, self.invocation_id, status,
                 dict(path=f"log/{self.project}"+str(newLogID), type="log"))
-        if status != 0:
-            print(f"Logging {self.json()} failed with {status}: {result}",
-                  file=sys.stderr)
 
     def _log_to(self, msg: str, dest: list):
         dest.append(msg
